@@ -1470,6 +1470,7 @@ class OpenShift:
         repository: Optional[str] = None,
         entities: Optional[str] = None,
         knowledge_path: Optional[str] = None,
+        mi_merge_path: Optional[str] = None,
         mi_used_for_thoth: Optional[bool] = False,
         mi_merge: Optional[bool] = False,
         *,
@@ -1486,7 +1487,8 @@ class OpenShift:
             "WORKFLOW_ID": workflow_id,
             "REPOSITORY": repository,
             "ENTITIES": entities,
-            "KNOWLEDGE_PATH": knowledge_path,
+            "KNOWLEDGE_PATH": knowledge_path or "",
+            "MI_MERGE_PATH": mi_merge_path or "",
             "MI_THOTH": "1" if mi_used_for_thoth else "0",
             "MI_MERGE": "1" if mi_merge else "0",
         }
@@ -1515,9 +1517,11 @@ class OpenShift:
         template_parameters = {
             "WORKFLOW_ID": workflow_id,
             "WEBHOOK_PAYLOAD": json.dumps(webhook_payload),
-            "KEBECHET_SLUG": slug,
         }
 
+        if slug is not None:
+            template_parameters["KEBECHET_SLUG"] = slug
+
         return self._schedule_workflow(
             workflow=self.workflow_manager.submit_kebechet,
             parameters={
@@ -2025,3 +2029,20 @@ class OpenShift:
                 "workflow_parameters": {},
             },
         )
+
+    def schedule_thoth_repo_init(
+        self, project_url: str, *, job_id: Optional[str] = None
+    ) -> Optional[str]:
+        """Schedule a workflow for running initial thoth-advise on a repo."""
+        workflow_id = job_id or self.generate_id("thoth-repo-init")
+        template_parameters = {
+            "WORKFLOW_ID": workflow_id,
+            "PROJECT_URL": project_url,
+        }
+        return self._schedule_workflow(
+            workflow=self.workflow_manager.submit_thoth_repo_init,
+            parameters={
+                "template_parameters": template_parameters,
+                "workflow_parameters": {},
+            },
+        )
